@@ -552,9 +552,9 @@ void wifi_ctrlfunc_unregister_drv(void)
 	}
 #endif /* !defined(CONFIG_DTS) */
 
-#if defined(CUSTOMER_HW)
+//#if defined(CUSTOMER_HW)
 	dhd_wlan_deinit_plat_data(adapter);
-#endif
+//#endif
 
 	kfree(dhd_wifi_platdata->adapters);
 	dhd_wifi_platdata->adapters = NULL;
