@@ -1997,7 +1997,7 @@ static void bq24192_irq_worker(struct work_struct *work)
 	 * In case of BQ24297, notify the power supply class about
 	 * the Input and the type of charger cable through cable properties
 	 */
-	if (chip->chip_type == BQ24297) {
+	if (chip->chip_type == BQ24297 || chip->chip_type == BQ24192I) {
 		ret = check_cable_status(chip, reg_status);
 		if (ret < 0)
 			dev_err(&chip->client->dev,
@@ -2860,7 +2860,7 @@ struct bq24192_platform_data tbg24296_drvdata = {
 	.num_supplicants = ARRAY_SIZE(bq24192_supplied_to),
 	.supported_cables = POWER_SUPPLY_CHARGER_TYPE_USB,
 	.sfi_tabl_present = true,
-	.max_cc = 3000,	/* 3000 mA */
+	.max_cc = 1540,	/* 2200mah * 0.7 mA */
 	.max_cv = 4350,	/* 4350 mV */
 	.max_temp = 45,	/* 45 DegC */
 	.min_temp = 0,	/* 0 DegC */
